<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Graphics.Printing.Workflow

Windows Runtime (WinRT) APIs for for the `Windows.Graphics.Printing.Workflow` namespace.

This package provides the `winrt.windows.graphics.printing.workflow` module.
